/* Copyright (C) 2024 GSI Helmholtzzentrum fuer Schwerionenforschung, Darmstadt
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Sergei Zharko [committer] */

/// \file   TrackingChainConfig.h
/// \date   18.02.2024
/// \brief  A configuration reader for the TrackingChain class
/// \author Sergei Zharko <s.zharko@gsi.de>

#pragma once

#include "yaml/Property.h"

#include <string>
#include <tuple>

namespace cbm::algo
{
  /// \struct TrackingChainConfig
  /// \brief Configuration reader for the TrackingChain class
  struct TrackingChainConfig {
    int fNofThreads;        ///< Number of threads for tracking
    std::string fsParName;  ///< Tracking parameter file name

    CBM_YAML_PROPERTIES(yaml::Property(&TrackingChainConfig::fNofThreads, "NofThreads", "Number of threads"),
                      yaml::Property(&TrackingChainConfig::fsParName, "ParName", "CA parameters input"));
  };
}  // namespace cbm::algo
