/* Copyright (C) 2024 FIAS Frankfurt Institute for Advanced Studies, Frankfurt / Main
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Felix Weiglhofer [committer], Dominik Smith */

#include "Unpack.h"

#include "log.hpp"

using namespace cbm::algo::tof;
using fles::Subsystem;

Unpack::Unpack(const ReadoutConfig& readout) : fReadout(readout)
{
  constexpr i64 SystemTimeOffset = 40;

  auto equipIdsTof = fReadout.GetEquipmentIds();
  for (auto& equip : equipIdsTof) {
    std::unique_ptr<tof::UnpackPar> par(new tof::UnpackPar());
    const size_t numElinks = fReadout.GetNumElinks(equip);
    for (size_t elink = 0; elink < numElinks; elink++) {
      tof::UnpackElinkPar elinkPar;
      elinkPar.fChannelUId = fReadout.Map(equip, elink);  // Vector of TOF addresses for this elink
      elinkPar.fTimeOffset = SystemTimeOffset;
      par->fElinkParams.push_back(elinkPar);
    }
    fAlgos[equip].SetParams(std::move(par));
    L_(debug) << "--- Configured equipment " << equip << " with " << numElinks << " elinks";
  }

  L_(info) << "--- Configured " << fAlgos.size() << " unpacker algorithms for TOF.";
}

Unpack::Result_t Unpack::operator()(const fles::Timeslice& ts) const
{
  constexpr int SystemVersion = 0x00;
  return DoUnpack(Subsystem::TOF, ts, SystemVersion);
}
